boss.starter - heros-boss 0.5.1 documentation

Skip to content
Back to top
View this page

# boss.starter

## Functions

`get_max_workers`(→ int) | Get the maximum number of worker processes to use.
`create_unique_instance_name`(→ str) | Creates a unique instance identifier consisting of the hostname and an UUID.
`run`([args]) |

## Module Contents

boss.starter.get_max_workers() → int

  Get the maximum number of worker processes to use.

  For Windows systems, caps the worker count at 32. For other platforms, returns the total CPU count.

  Returns:

    The maximum number of worker processes to use

boss.starter.create_unique_instance_name() → str

  Creates a unique instance identifier consisting of the hostname and an UUID.

  Returns:

    A unique identifier.

boss.starter.run(args=None)